@@ -41,7 +41,7 @@ class ClassificationTrainArguments:
         metadata={"help": "save top k model checkpoints."}
     )
     monitor: str = field(
-        default="max val_acc",
+        default="min val_loss",
         metadata={"help": "monitor condition (save top k)"}
     )
     seed: int = field(
