@@ -1,11 +1,15 @@
-from flask_ngrok import run_with_ngrok
 from flask import Flask, request, jsonify, render_template
 
 
-def get_web_service_app(inference_fn):
+def get_web_service_app(inference_fn, is_colab=True):
 
     app = Flask(__name__, template_folder='')
-    run_with_ngrok(app)
+    if is_colab:
+        from flask_ngrok import run_with_ngrok
+        run_with_ngrok(app)
+    else:
+        from flask_cors import CORS
+        CORS(app)
 
     @app.route('/')
     def index():
